CLAM Data API
==================================

The CLAM Data API is at the heart of CLAM. It contains various data structures CLAM uses, such as the Profiles, Input Templates, Output Templates, Metadata, etc... This API is used by CLAM internally but is also designed to be used in your system wrapper scripts and clients!

.. automodule:: clam.common.data
    :members:
    :undoc-members:

